package tokens

import (
	"github.com/shopspring/decimal"

	"git.lehouerou.net/laurent/sorare/graphql"
	"git.lehouerou.net/laurent/sorare/types"
)

type TokenCardMetadata struct {
	PlayerDisplayName string `graphql:"playerDisplayName"`
	PlayerSlug        string `graphql:"playerSlug"`
	Rarity            string `graphql:"rarity"`
	SerialNumber      int    `graphql:"serialNumber"`
	SeasonStartYear   int    `graphql:"seasonStartYear"`
	SingleCivilYear   bool   `graphql:"singleCivilYear"`
	Supply            int    `graphql:"supply"`
	TeamSlug          string `graphql:"teamSlug"`
}

type Token struct {
	AssetId              string     `graphql:"assetId"`
	Collection           string     `graphql:"collection"`
	ContractAddress      string     `graphql:"contractAddress"`
	EthereumId           string     `graphql:"ethereumId"`
	Id                   graphql.Id `graphql:"id"`
	LatestEnglishAuction *struct {
		Id graphql.Id `graphql:"id"`
	} `graphql:"latestEnglishAuction"`
	LiveSingleSaleOffer *struct {
		Id graphql.Id `graphql:"id"`
	} `graphql:"liveSingleSaleOffer"`
	Metadata struct {
		Football TokenCardMetadata `graphql:"... on TokenCardMetadataInterface"`
	}
	Name            string          `graphql:"name"`
	PictureUrl      string          `graphql:"pictureUrl(derivative: \"tinified\")"`
	PrivateMinPrice decimal.Decimal `graphql:"privateMinPrice"`
	PublicMinPrice  decimal.Decimal `graphql:"publicMinPrice"`
	Slug            string          `graphql:"slug"`
	Sport           string          `graphql:"sport"`

	OwnershipHistory []TokenOwner `graphql:"ownershipHistory"`
}

type AllNftsParams struct {
	Sport []types.Sport `graphql:"sport"`
}
